/*
 * LAR1 Arduino shield 用 UART スルー
 * Ver 0.01
 *  _ ____           _            _                  _
 * |_|___ \      ___| | ___  __ _| |_ _ _____  ____ |_| ___ ____
 *  _  __) | _  / __) |/ __)/ _(_   _| / / _ \|  _ \ _ / __/ ___)
 * | |/ __/ |_||  __| |  __| (__ | |_|  / (_) | | | | | (__\___ \
 * |_|_____|    \___)_|\___)\___)\___|_| \___/|_| |_|_|\___)____/
 * (C)2020 i2-electronics,Inc
 * 
 * このスケッチはArduinoのUARTとLRA1をスルーで接続します。
 * シリアルモニタからLAR1を直接制御することができます。
 * 115200bpsではLAR1からのシリアルデーターを取りこぼしたり文字化けが発生するので
 * 通常動作では9600bps等に設定して使用することを推奨します。
 * （LAR1も9600bpsに設定してください。BASICコマンドで"BAUD=9600:SSAVE"）
 * LRA1のFirmwareをupdateする場合は、115200bpsのままで使用してUpdate用アプリでは
 * 「Slow mode」に設定してください。
 * 
 * Arduino Unoでこのスケッチの動作を確認しています。
 * Leonardo,MEGA2560など6番ピンをソフトシリアルのRXに使用できな機種では、
 * 6番ピンと10番ピン等をジャンパー接続し、ソフトシリアルの設定も変更してください。
 */

#include <SoftwareSerial.h>

#define UART_BAUDRATE       115200

#define Lora_En_Pin         2         // LoRa-EN
#define Lora_WakeUp_Pin     3         // LoRa-WakeUp
#define Lora_WakeChk_Pin    4         // LoRa-WakeCheck
#define Lora_Reset_Pin      5         // LoRa-Reset
#define Lora_Rx_Pin         6         // LoRa-Rx
#define Lora_Tx_Pin         7         // LoRa-Tx

SoftwareSerial LoraSerial(Lora_Rx_Pin, Lora_Tx_Pin); // RX, TX

void setup() {
  Serial.begin(UART_BAUDRATE);
  while (!Serial);
  LoraSerial.begin(UART_BAUDRATE);
 
  pinMode(Lora_En_Pin, OUTPUT);
  pinMode(Lora_Reset_Pin, OUTPUT);
  pinMode(Lora_WakeUp_Pin, OUTPUT);
  pinMode(Lora_WakeChk_Pin, INPUT);

  digitalWrite(Lora_WakeUp_Pin, LOW);   // LoRa-WakeUp = Low
  digitalWrite(Lora_En_Pin, HIGH);      // LoRa-En = High
  digitalWrite(Lora_Reset_Pin, LOW);    // LoRa-Reset = Low
  delay(100);
  pinMode(Lora_Reset_Pin, INPUT);       // LoRa-Reset = Hi-Z
}

void loop() {
  if (LoraSerial.available()) Serial.write(LoraSerial.read());
  if (Serial.available()) LoraSerial.write(Serial.read());
}
